"""This is an emoji map for usage in shell outputs.

:author: Julian M. Kleber
"""
from emoji import emojize


angered_face = emojize(":enraged_face:")
face_blowing_kiss = emojize(":face_blowing_a_kiss:")
fearful_face = emojize(":fearful_face:")
face_screaming_in_fear = emojize(":face_screaming_in_fear:")
magic_wand = emojize(":magic_wand:")
pensive_face = emojize(":pensive_face:")
kissing_cat = emojize(":kissing_cat:")
face_with_rolling_eyes = emojize(":face_with_rolling_eyes:")
